@@ -1,6 +1,6 @@
 # from .modules.PyQt5.QtWidgets import QApplication
-from modules.screeninfo.screeninfo import get_monitors
-from modules.mss import mss
+from .modules.screeninfo.screeninfo import get_monitors
+from .modules import mss
 from PyQt5.QtWidgets import QApplication
 
 import sys
@@ -49,10 +49,10 @@ class DisplayInfo():
 
 
 
-if __name__ == "__main__":
-    dis = DisplayInfo()
-    # dis.print_scale_factors()
-    # dis.print_screen_info()
-    print(dis.get_screen_info())
-    print(dis.get_scale_factor())
+# if __name__ == "__main__":
+#     dis = DisplayInfo()
+#     # dis.print_scale_factors()
+#     # dis.print_screen_info()
+#     print(dis.get_screen_info())
+#     print(dis.get_scale_factor())
     
\ No newline at end of file
